@@ -27,8 +27,7 @@ logger = logging.getLogger(__name__)
 
 class CrateDbQuery(object):
 
-    """ Parameterized SQL queries using Python DBI protocol...
-    """
+    """Parameterized SQL queries using Python DBI protocol..."""
 
     def __init__(self, dbcon, verbose=True):
         self.__dbcon = dbcon
@@ -40,13 +39,13 @@ class CrateDbQuery(object):
         self.__warningAction = "default"
 
     def sqlTemplateCommandMany(self, sqlTemplate, valueLists=None):
-        """  Execute a batch sql commands followed by a single commit. Commands are
-             are describe in a template with an associated list of values.
+        """Execute a batch sql commands followed by a single commit. Commands are
+         are describe in a template with an associated list of values.
 
-            cursor.executemany("INSERT INTO locations (name, date, kind, position) VALUES (?, ?, ?, ?)",
-                ...                [('Cloverleaf', '2007-03-11', 'Quasar', 7),
-                ...                 ('Old Faithful', '2007-03-11', 'Quasar', 7)])
-                [{u'rowcount': 1}, {u'rowcount': 1}]
+        cursor.executemany("INSERT INTO locations (name, date, kind, position) VALUES (?, ?, ?, ?)",
+            ...                [('Cloverleaf', '2007-03-11', 'Quasar', 7),
+            ...                 ('Old Faithful', '2007-03-11', 'Quasar', 7)])
+            [{u'rowcount': 1}, {u'rowcount': 1}]
 
         """
         lenR = 0
@@ -80,11 +79,11 @@ class CrateDbQuery(object):
         return lenR - iFail
 
     def sqlTemplateCommand(self, sqlTemplate=None, valueList=None):
-        """  Execute sql template command with associated value list.
+        """Execute sql template command with associated value list.
 
-             Insert one row -
+        Insert one row -
 
-             Errors and warnings that generate exceptions are caught by this method.
+        Errors and warnings that generate exceptions are caught by this method.
         """
         valueList = valueList if valueList else []
         try:
@@ -104,15 +103,15 @@ class CrateDbQuery(object):
         return False
 
     def sqlTemplateCommandList(self, sqlTemplateValueList=None):
-        """  Execute sql template command with associated value list.
+        """Execute sql template command with associated value list.
 
-             Input -
+        Input -
 
-             sqlTemplateValueList [(sqlTemplate,vList), (sqlTemplate, vlist), ... ]
+        sqlTemplateValueList [(sqlTemplate,vList), (sqlTemplate, vlist), ... ]
 
-             Insert on row -
+        Insert on row -
 
-             Errors and warnings that generate exceptions are caught by this method.
+        Errors and warnings that generate exceptions are caught by this method.
         """
         vL = []
         iFail = 0
@@ -148,7 +147,7 @@ class CrateDbQuery(object):
         return ii - iFail + 1
 
     def sqlCommandList(self, sqlCommandList):
-        """  Execute the input list of SQL commands catching exceptions from the server.
+        """Execute the input list of SQL commands catching exceptions from the server.
 
         The treatment of warning is controlled by a prior setting of self.setWarnings("error"|"ignore"|"default")
         """
@@ -177,8 +176,7 @@ class CrateDbQuery(object):
         return False
 
     def sqlCommand(self, queryString):
-        """   Execute SQL command catching exceptions returning no data from the server.
-        """
+        """Execute SQL command catching exceptions returning no data from the server."""
         try:
             curs = self.__dbcon.cursor()
             curs.execute(queryString)
@@ -198,8 +196,7 @@ class CrateDbQuery(object):
         return []
 
     def __fetchIter(self, cursor, rowSize=1000):
-        """ Chunked iterator to manage results fetches to mysql server
-        """
+        """Chunked iterator to manage results fetches to mysql server"""
         while True:
             results = cursor.fetchmany(rowSize)
             if not results:
@@ -208,8 +205,7 @@ class CrateDbQuery(object):
                 yield result
 
     def selectRows(self, queryString):
-        """ Execute SQL command and return list of lists for the result set.
-        """
+        """Execute SQL command and return list of lists for the result set."""
         rowList = []
         try:
             curs = self.__dbcon.cursor()
@@ -240,8 +236,7 @@ class CrateDbQuery(object):
         return []
 
     def simpleQuery(self, selectList=None, fromList=None, condition="", orderList=None, returnObj=None):
-        """
-        """
+        """"""
         #
         selectList = selectList if selectList else []
         fromList = fromList if fromList else []
